@@ -1,8 +1,15 @@
+"""
+This is the entry point for main "kuyruk" executable command.
+It implements the command line parsing for subcommands and configuration.
+
+"""
+
 from __future__ import absolute_import
 import os
 import ast
 import logging
 import argparse
+
 from kuyruk import __version__, importer, Kuyruk
 from kuyruk.master import Master
 from kuyruk.config import Config
@@ -91,10 +98,18 @@ def add_config_options(parser):
 def create_config(args):
     """Creates Config object and overrides it's values from args."""
     config = Config()
-    if args.config:
-        config.from_pyfile(args.config)
 
-    # Override values in config
+    if args.config:
+        # Load config file from command line option
+        config.from_pyfile(args.config)
+    else:
+        # Load config file from environment variable
+        env_config = os.environ.get('KUYRUK_CONFIG')
+        if env_config:
+            assert os.path.isabs(env_config)
+            config.from_pyfile(env_config)
+
+    # Override values in config from command line
     for key, value in vars(args).iteritems():
         if value is not None:
             key = to_attr(key)
@@ -105,6 +120,7 @@ def create_config(args):
                     pass
                 setattr(config, key, value)
 
+    # This option is used internally when master spawns workers.
     if args.delete_config:
         os.unlink(args.config)
 
