@@ -312,12 +312,17 @@ class Worker(KuyrukProcess):
     def register_signals(self):
         super(Worker, self).register_signals()
         signal.signal(signal.SIGTERM, self.handle_sigterm)
+        signal.signal(signal.SIGQUIT, self.handle_sigquit)
 
     def handle_sigterm(self, signum, frame):
         """Initiates a warm shutdown."""
         logger.warning("Catched SIGTERM")
         self.warm_shutdown()
 
+    def handle_sigquit(self, signum, frame):
+        """Send ACK for the current task and exit."""
+        pass
+
     def warm_shutdown(self, sigint=False):
         """Shutdown gracefully."""
         super(Worker, self).warm_shutdown(sigint)
